Shape

Struct Shape 

pub struct Shape<'a> { /* private fields */ }
The shape builder

Implementations

Source

impl<'a> Shape<'a>

pub fn new() -> Self

Create an empty shape to start building.

pub fn fill_color(self, color: Color) -> Self

Set the fill color of the shape.

pub fn fill_paint(self, texture: &'a Paint<'_>) -> Self

Set the fill paint of the shape. This allows for more complex fills such as gradients and patterns.

pub fn no_fill(self) -> Self

Don’t fill the shape. If this is not called the shape will not be closed.

pub fn no_stroke(self) -> Self

Don’t stroke the shape.

pub fn stroke_color(self, color: Color) -> Self

Set the stroke color of the shape.

pub fn stroke_paint(self, paint: &'a Paint<'_>) -> Self

Set the stroke paint of the shape. This allows for more complex fills such as gradients and patterns.

pub fn stroke_weight(self, weight: f32) -> Self

Set the stroke width of the shape.

pub fn line_cap(self, cap: LineCap) -> Self

Set the line cap of the shape.

pub fn line_join(self, join: LineJoin) -> Self

Set the line join of the shape.

pub fn miter_limit(self, limit: f32) -> Self

pub fn stroke_dash(self, dash: StrokeDash) -> Self

Set the stroke dash of the shape.

pub fn points(self, pts: &[Point]) -> Self

Set the points that determine the shape.

pub fn get_points(&self) -> &[Point]

Get points.

pub fn rect_ltrb(self, lt: Point, rb: Point) -> Self

Interpret the points as a rectangle. The first point is the top left corner and the second point is the bottom right corner.

pub fn rect_xywh(self, xy: Point, wh: Point) -> Self

Inerpret the points as a rectangle. The first point is the top left corner and the second point is the size of the rectangle.

pub fn rect_cwh(self, c: Point, wh: Point) -> Self

Inerpret the points as a rectangle. The first point is the center of the rectangle and the second point is the size of the rectangle.

pub fn circle(self, center: Point, radius: f32) -> Self

Create circle from it’s center and radius.

pub fn ellipse(self, center: Point, width: f32, height: f32) -> Self

Create ellispse from it’s center, width and heighr.

pub fn polygon(self, center: Point, radius: f32, sides: u32) -> Self

Create a polygon from it’s center, radius and number of sides.

pub fn star( self, center: Point, inner_radius: f32, outer_radius: f32, sides: u32, ) -> Self

Create a star from it’s center, inner radius, outer radius, number of sides and smoothness parameter.

pub fn pearl<R: RngCore>( self, center: Point, a: f32, b: f32, sides: u32, smoothness: u32, rng: &mut R, ) -> Self

A pearl is a deformed polygon using the normal distribution to alter the location of each point. The a and b parameters control the width and height of the pearl. The sides parameter controls the number of sides of the polygon. The smoothness parameter controls the smoothnes of the polygon. using the Chaiken algorithm.

pub fn quad(self) -> Self

Interpret the points as a quadratic bezier curve. The first point is the start point, the second point is the control point and the third point is the end point and so on.

pub fn cubic(self) -> Self

Interpret the points as a cubic bezier curve. The first point is the start point, the second point is the first control point, the third point is the second control point and the fourth point is the end point and so on.

pub fn line(self, from: Point, to: Point) -> Self

Create a line from it’s start and end points.

pub fn fill_rule(self, fillrule: FillRule) -> Self

Set the fill rule for the shape.

pub fn transform(self, transform: &Transform) -> Self

Set the transform for the shape.

pub fn cartesian<T: AsPrimitive<f32>>(self, width: T, height: T) -> Self

Interpret points as cartiesian coordinates with center at (0, 0).

pub fn draw(self, canvas: &mut Canvas)

Draw the shape to the canvas.